==> hcs_utils-1.0rc1.tar.gz: hcs_utils-1.0rc1/hcs_utils/storage.py <==
# -*- coding: UTF-8 -*-
# vim: fileencoding=UTF-8 filetype=python ff=unix et ts=4 sw=4 sts=4 tw=120
#
# Copyright (c) 2010, Christer Sjöholm -- hcs AT furuvik DOT net
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

class Storage(object):
    """
    A Storage object wraps a dictionary.
    In addition to `obj['foo']`, `obj.foo` can also be used for accessing values.

    Wraps the dictionary instead of extending it so that the number of names that
    can conflict with keys in the dict is kept minimal.

        >>> o = Storage(a=1)
        >>> o.a
        1
        >>> o['a']
        1
        >>> o.a = 2
        >>> o['a']
        2
        >>> del o.a
        >>> o.a
        Traceback (most recent call last):
            ...
        AttributeError: 'a'

        Based on Storage in web.py (public domain)
    """
    def __init__(self, _dict=None, **kwargs):
        self._dict = _dict or {}
        self._dict.update(kwargs)

    def get_dict(self):
        ''' Get the contained dict.'''
        return self._dict

    def __getattr__(self, key):
        try:
            return self._dict[key]
        except KeyError, k:
            raise AttributeError, k

    def __setattr__(self, key, value):
        if key == '_dict':
            object.__setattr__(self, key, value)
        else:
            self._dict[key] = value

    def __delattr__(self, key):
        try:
            del self._dict[key]
        except KeyError, k:
            raise AttributeError, k

    # For container methods pass-through to the underlying dict.
    def __getitem__(self, key):
        return self._dict[key]

    def __setitem__(self, key, value):
        self._dict[key] = value

    def __delitem__(self, key):
        del self._dict[key]

    def __repr__(self):
        return '<Storage ' + repr(self._dict) + '>'

==> hcs_utils-1.1.tar.gz: hcs_utils-1.1/hcs_utils/storage.py <==
# -*- coding: UTF-8 -*-
# vim: fileencoding=UTF-8 filetype=python ff=unix et ts=4 sw=4 sts=4 tw=120
#
# Copyright (c) 2010, Christer Sjöholm -- hcs AT furuvik DOT net
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

class Storage(object):
    """
    A Storage object wraps a dictionary.
    In addition to `obj['foo']`, `obj.foo` can also be used for accessing values.

    Wraps the dictionary instead of extending it so that the number of names that
    can conflict with keys in the dict is kept minimal.

        >>> o = Storage(a=1)
        >>> o.a
        1
        >>> o['a']
        1
        >>> o.a = 2
        >>> o['a']
        2
        >>> del o.a
        >>> o.a
        Traceback (most recent call last):
            ...
        AttributeError: 'a'

        Based on Storage in web.py (public domain)
    """
    def __init__(self, _dict=None, **kwargs):
        self._dict = _dict or {}
        self._dict.update(kwargs)

    def get_dict(self):
        ''' Get the contained dict.'''
        return self._dict

    def __getattr__(self, key):
        try:
             if key == '_dict': # prevent recursion (triggered by pickle.load()
                raise AttributeError('No such attribute')
            return self._dict[key]
        except KeyError, k:
            raise AttributeError, k

    def __setattr__(self, key, value):
        if key == '_dict':
            object.__setattr__(self, key, value)
        else:
            self._dict[key] = value

    def __delattr__(self, key):
        try:
            del self._dict[key]
        except KeyError, k:
            raise AttributeError, k

    # For container methods pass-through to the underlying dict.
    def __getitem__(self, key):
        return self._dict[key]

    def __setitem__(self, key, value):
        self._dict[key] = value

    def __delitem__(self, key):
        del self._dict[key]

    def __repr__(self):
        return '<Storage ' + repr(self._dict) + '>'
